mlpy.automl package
===================

.. automodule:: mlpy.automl
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.automl.advanced_automl
   mlpy.automl.feature_engineering
   mlpy.automl.meta_learning
   mlpy.automl.simple_automl
   mlpy.automl.tuning
